[−][src]Struct lyon_path::PathState
Represents the current state of a path while it is being built.
Methods
impl PathState[src]
pub fn new() -> Self[src]
pub fn current_position(&self) -> Point[src]
The current position.
pub fn start_position(&self) -> Point[src]
The position at the start of the current sub-path.
pub fn move_to(&mut self, to: Point)[src]
pub fn line_to(&mut self, to: Point)[src]
pub fn close(&mut self)[src]
pub fn quadratic_bezier_to(&mut self, ctrl: Point, to: Point)[src]
pub fn cubic_bezier_to(&mut self, _ctrl1: Point, ctrl2: Point, to: Point)[src]
pub fn arc(
&mut self,
center: Point,
radii: Vector,
sweep_angle: Angle,
x_rotation: Angle
)[src]
&mut self,
center: Point,
radii: Vector,
sweep_angle: Angle,
x_rotation: Angle
)
pub fn get_smooth_cubic_ctrl(&self) -> Point[src]
pub fn get_smooth_quadratic_ctrl(&self) -> Point[src]
pub fn relative_to_absolute(&self, v: Vector) -> Point[src]